@@ -11,7 +11,7 @@ if [ -z "$DEBCRAFT_PPA" ] || [ -n "$DEBUG" ]
 then
   log_info "No environment variable DEBCRAFT_PPA defined, skip upload to Launchpad"
   echo
-  log_info "See https://help.launchpad.net/Packaging/PPA on how anybody can sign"
+  log_info "See $(clickable_link "help.launchpad.net/Packaging/PPA") on how anybody can sign"
   log_info "up for an account on Launchpad to build Debian/Ubuntu packages on"
   log_info "multiple architectures and release them in a personal repository."
   return # skip the rest of this file and return bach to calling script
@@ -49,7 +49,8 @@ do
   case $selection in
     ''|[Yy]*)
       eval "$CMD"
-      log_info "Review build results at https://launchpad.net/~${PPA_OWNER}/+archive/ubuntu/${PPA_NAME}/+builds?build_text=&build_state=all"
+      PPA_URL="launchpad.net/~${PPA_OWNER}/+archive/ubuntu/${PPA_NAME}/+builds?build_text=&build_state=all"
+      log_info "Review build results at $(clickable_link "$PPA_URL")"
       break
       ;;
     [Nn]*)
