@@ -12,14 +12,21 @@ set -o pipefail
 # latest tag and commit contents to know if they actually should be rolled back
 # or not
 function revert_import() {
-  git checkout "$UPSTREAM_BRANCH" && git tag -d "$(git tag --points-at)" && git reset --hard "$UPSTREAM_BRANCH_COMMIT_ID_BEFORE"
+  log_info "Attempting to revert the changes done by 'debcraft update'"
+  log_command git checkout "$UPSTREAM_BRANCH" \
+  && log_command git tag -d "$(git tag --points-at)" \
+  && log_command git reset --hard "$UPSTREAM_BRANCH_COMMIT_ID_BEFORE"
 
   if [ "$PRISTINE_TAR" = "True" ]
   then
-    git checkout pristine-tar && git reset --hard "$PRISTINE_TAR_COMMIT_ID_BEFORE"
+    log_command git checkout pristine-tar \
+    && log_command git reset --hard "$PRISTINE_TAR_COMMIT_ID_BEFORE"
   fi
 
-  git checkout "$DEBIAN_BRANCH" && git reset --hard "$DEBIAN_BRANCH_COMMIT_ID_BEFORE"
+  log_command git checkout "$DEBIAN_BRANCH" \
+  && log_command git reset --hard "$DEBIAN_BRANCH_COMMIT_ID_BEFORE"
+
+  log_info "Successfully reverted the changes done by 'debcraft update'"
 }
 
 # Get configs
@@ -141,16 +148,11 @@ then
   log_debug_var PRISTINE_TAR_COMMIT_ID_BEFORE
 fi
 
-if [ -n "$DEBUG" ]
-then
-  set -x
-fi
-
 log_info "Ensuring local git checkout is up-to-date with git remote '$VCS_GIT'"
 
 # Make sure latest commits are fetched from the official vcs-git location
 git remote add vcs-git "$VCS_GIT"
-gbp pull --track-missing vcs-git
+log_command gbp pull --track-missing vcs-git
 git remote remove vcs-git
 # @TODO: If git-buildpackage adds support for fetching with URL, the above could
 # be replaced with simply:
@@ -173,8 +175,9 @@ OPEN_MRS="$(curl -s https://salsa.debian.org/api/v4/projects/"$SALSA_PROJECT_API
 
 if [ -n "$OPEN_MRS" ]
 then
-  log_warn "This project has open Merge Requests that should probably be reviewed first:"
+  log_info "This project has open Merge Requests that should probably be reviewed first:"
   echo "$OPEN_MRS"
+  echo
   read -r -p "Press Ctrl+C to abort and attend Merge Requests, or press enter to proceed"
 fi
 
@@ -193,13 +196,13 @@ log_info "Fetching upstream git tags from $(git remote get-url upstreamvcs) to"
          "see if there are new release tags"
 # Use `--verbose` so there is always some output, capture stderr as `--verbose`
 # seems to use it, and `tail` to avoid too much output
-git fetch upstreamvcs --tags --verbose 2>&1 | tail -n 5
+log_command_cap_output git fetch upstreamvcs --tags --verbose
 
 # @TODO: If Debian packaging stored upstream OpenPGP or SSH keys, the next step
 # after fetching tags would be to run `git verify-tag`
 
-log_info "Run git-buildpackage with uscan to import new upstream version (if found)"
-gbp import-orig --uscan --no-interactive --postimport="dch -v %(version)s 'New upstream release'"
+log_info "Run 'gbp import-orig --uscan' to import new upstream version (if found)"
+log_command gbp import-orig --uscan --no-interactive --postimport="dch -v %(version)s 'New upstream release'"
 
 # @TODO: Note that if upstream was already imported to the git repository, but
 # `debcraft update` is run on some other branch, `uscan` won't find anything and
@@ -213,20 +216,83 @@ gbp import-orig --uscan --no-interactive --postimport="dch -v %(version)s 'New u
 log_info "Pre-populate debian/changelog with appropriate update and launch" \
          "editor for proof-reading and tweaking"
 # Note that this will use whatever user has configured as their preferred 'sensible-editor'
-gbp dch --distribution=UNRELEASED --spawn-editor=always --commit --commit-msg="Update changelog and refresh patches after %(version)s import" -- debian
+log_command gbp dch --distribution=UNRELEASED --spawn-editor=always --commit --commit-msg="Update changelog and refresh patches after %(version)s import" -- debian
 
 # Remove Debian revision from `%(version)s` to have pure upstream version in commit message
-git commit --amend --no-edit --message="$(git log -1 --pretty=%s | sed 's/\([0-9]\+\.[0-9.]\+\)-[0-9]\+/\1/g')"
+message=$(git log -1 --pretty=%s)
+message="${message/ [0-9]*:/ }"  # Remove epoch (e.g., " 1:") while preserving context
+message="${message//-[0-9]* / }"  # Remove Debian revision (e.g., "-0ubuntu1") while keeping following word separated
+git commit --amend --no-edit --message="$message"
 
 log_info "Rebase debian/patches/* on this new upstream version"
-gbp pq import --force --time-machine=10
-git rebase -
-gbp pq export --drop
-git commit --amend --all --no-edit
+log_command gbp pq import --force --time-machine=10
 
-if [ -n "$DEBUG" ]
+# Perform rebase with safeguard
+if ! git rebase -
 then
-  set +x
+    # Failure path - instruct user to use separate shell session
+    log_warn "Patch rebase failed due to conflicts"
+    echo
+    log_info "You must resolve these conflicts in a SEPARATE shell session before 'debcraft update' can proceed"
+    echo
+    echo "  1. Open a NEW shell session / terminal window"
+    echo "  2. Ensure you are in directory $(pwd)"
+    echo "  3. To start resolving the merge conflict, run:"
+    echo "       git mergetool"
+    echo "  4. After exiting the merge tool, run:"
+    echo "       git rebase --continue"
+    echo "  5. Repeat steps 3-4 until you see 'Successfully rebased and updated'"
+    echo "  6. Return to THIS session when rebase is complete and press Enter to continue"
+    echo
+
+    while true
+    do
+        read -r -p "Press [Enter] to continue after rebase, or type [a]bort to revert all changes: " choice
+
+        case $choice in
+            '')
+                # Verify rebase actually completed successfully
+                if [ -d .git/rebase-merge ] || [ -d .git/rebase-apply ]
+                then
+                    log_warn "Rebase appears to still be in progress! Please ensure you completed the rebase in the other shell."
+                    echo
+                else
+                    break
+                fi
+                ;;
+            [aA])
+                log_info "Aborting update and cleaning up..."
+
+                # Abort rebase if still in progress
+                if [ -d .git/rebase-merge ] || [ -d .git/rebase-apply ]
+                then
+                    git rebase --abort
+                fi
+
+                # Drop patch-queue branch
+                gbp pq drop 2>/dev/null || true
+
+                # Revert entire import
+                revert_import
+                exit 1
+                ;;
+            *)
+                log_warn "Invalid input. Press [Enter] after rebase, or type 'a' to abort."
+                ;;
+        esac
+    done
+fi
+
+# Verify we're on the patch-queue branch and export patches
+CURRENT_BRANCH=$(git rev-parse --abbrev-ref HEAD)
+if [[ "$CURRENT_BRANCH" == patch-queue/* ]]
+then
+    log_command gbp pq export --drop
+    log_command git commit --amend --all --no-edit
+else
+    log_error "Unexpected branch state: '$CURRENT_BRANCH' not a patch-queue branch."
+    revert_import
+    exit 1
 fi
 
 echo
@@ -235,13 +301,14 @@ echo
 
 while true
 do
-  read -r -p "Was the new upstream version import successful and should the result be kept, or reverted [K|r]?  " selection
+  read -r -p "Was the new upstream version import successful and should the result be [k]ept, or reverted [K|r]?  " selection
   case $selection in
     ''|[Kk]*)
+      echo
       IMPORT_BRANCH_NAME="next/$(git branch --show-current)"
       log_info "Run the following commands to have the import on a new branch" \
               "and publish it for review in your project fork on Salsa:"
-      echo "  git checkout -b $IMPORT_BRANCH_NAME"
+      echo "  git checkout -B $IMPORT_BRANCH_NAME"
       echo "  git checkout $DEBIAN_BRANCH && git reset --hard $DEBIAN_BRANCH_COMMIT_ID_BEFORE"
       echo "  git checkout $IMPORT_BRANCH_NAME"
       echo "  git push --set-upstream <fork> $IMPORT_BRANCH_NAME"
@@ -262,6 +329,7 @@ do
       break
       ;;
     [Rr]*)
+      echo
       log_warn "Reverting upstream import!"
       revert_import
       break
